<?php
// $Id: gsitemap.php,v 1.1.2.4 2007/04/25 21:45:07 darrenoh Exp $

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Define additional links to add to the site map.
 *
 * This hook allows modules to add additional links to the site map. Links
 * may be associated with nodes, terms, or users, as shown in the example.
 *
 * @param $type
 *   If given, the type of link to associate additional links with.
 * @param $excludes
 *   If given, the criterion for excluding links.
 * @return
 *   An array of links or an empty array.
 */
function hook_gsitemap($type = NULL, $excludes = "''") {
  $additional = array();
  switch ($type) {
    case 'node':
      // Add pages created by the node paging module.
      if (module_exists('comment')) {
        $result = db_query("
          SELECT p.pages, n.nid, n.type, n.promote, s.comment_count, n.changed, g.previously_changed, s.last_comment_timestamp, g.previous_comment, g.priority_override
          FROM {node} n
          INNER JOIN {paging} p
          ON n.nid = p.nid
          LEFT JOIN {node_comment_statistics} s
          ON n.nid = s.nid
          LEFT JOIN {gsitemap} g
          ON n.nid = g.nid
          WHERE n.status > 0
          AND (g.priority_override >= 0 OR g.priority_override IS NULL)
          AND n.type NOT IN ($excludes)
          AND p.pages > 1
        ");
        $maxcomments = db_result(db_query('SELECT MAX(comment_count) FROM {node_comment_statistics}'));
      }
      else {
        $result = db_query("
          SELECT p.pages, n.nid, n.type, n.promote, n.changed, g.previously_changed, g.priority_override
          FROM {node} n
          INNER JOIN {paging} p
          ON n.nid = p.nid
          LEFT JOIN {gsitemap} g
          ON n.nid = g.nid
          WHERE n.status > 0
          AND (g.priority_override >= 0 OR g.priority_override IS NULL)
          AND n.type NOT IN ($excludes)
          AND p.pages > 1
        ");
        $maxcomments = 0;
      }
      while ($node = db_fetch_object($result)) {
        $pri = _gsitemap_calc_priority($node, $maxcomments);
        if ($pri < 0) {
          continue;
        }
        $age = time() - $node->changed;
        if (!empty($node->previously_changed)) {
          $interval = $node->changed - $node->previously_changed;
        }
        else {
          $interval = 0;
        }
        for ($count = 1; $count < $node->pages; ++ $count) {
          $entry = array(
            'nid' => $node->nid,
            '#loc' => url('node/'. $node->nid, "page=0,$count", NULL, TRUE),
            '#lastmod' => gmdate('Y-m-d\TH:i:s+00:00', $node->changed),
            '#changefreq' => gsitemap_frequency($age, $interval),
            '#priority' => $pri,
          );
          $additional[] = $entry;
        }
      }
      break;
    case 'term':
    case 'user':
      break;
    default:
      // Add arbitrary additional links.
      $result = db_query('SELECT * FROM {gsitemap_additional}');
      while ($link = db_fetch_object($result)) {
        $age = time() - $link->last_changed;
        if (!empty($link->previously_changed)) {
          $interval = $link->last_changed - $link->previously_changed;
        }
        else {
          $interval = 0;
        }
        $entry = array(
          '#loc' => url($link->url, NULL, NULL, TRUE),
          '#lastmod' => gmdate('Y-m-d\TH:i:s+00:00', $link->last_changed),
          '#changefreq' => gsitemap_frequency($age, $interval),
          '#priority' => $link->priority,
        );
        $additional[] = $entry;
      }
  }
  return $additional;
}

/**
 * @} End of "addtogroup hooks".
 */

